
# Slot: versionOf




URI: [biolink:versionOf](https://w3id.org/biolink/vocab/versionOf)

## Domain and Range

[DataSetVersion](DataSetVersion.md) ->  <sub>OPT</sub> [DataSet](DataSet.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [DataSetSummary](DataSetSummary.md)
 * [DataSetVersion](DataSetVersion.md)
 * [DistributionLevel](DistributionLevel.md)
